@@ -9,6 +9,7 @@ service UnitTestModelController {
     rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
     rpc List(UnitTestModelListRequest) returns (UnitTestModelListResponse) {}
     rpc ListWithExtraArgs(UnitTestModelListWithExtraArgsRequest) returns (UnitTestModelListExtraArgsResponse) {}
+    rpc PartialUpdate(UnitTestModelPartialUpdateRequest) returns (UnitTestModelResponse) {}
     rpc Retrieve(UnitTestModelRetrieveRequest) returns (UnitTestModelResponse) {}
     rpc Stream(UnitTestModelStreamRequest) returns (stream UnitTestModelResponse) {}
     rpc Update(UnitTestModelRequest) returns (UnitTestModelResponse) {}
@@ -36,6 +37,13 @@ message UnitTestModelListWithExtraArgsRequest {
     bool archived = 1;
 }
 
+message UnitTestModelPartialUpdateRequest {
+    int32 id = 1;
+    string title = 2;
+    string text = 3;
+    repeated string _partial_update_fields = 4;
+}
+
 message UnitTestModelRequest {
     int32 id = 1;
     string title = 2;
@@ -100,6 +108,7 @@ service RelatedFieldModelController {
     rpc Create(RelatedFieldModelRequest) returns (RelatedFieldModelResponse) {}
     rpc Destroy(RelatedFieldModelDestroyRequest) returns (google.protobuf.Empty) {}
     rpc List(RelatedFieldModelListRequest) returns (RelatedFieldModelListResponse) {}
+    rpc PartialUpdate(RelatedFieldModelPartialUpdateRequest) returns (RelatedFieldModelResponse) {}
     rpc Retrieve(RelatedFieldModelRetrieveRequest) returns (RelatedFieldModelResponse) {}
     rpc Update(RelatedFieldModelRequest) returns (RelatedFieldModelResponse) {}
 }
@@ -132,6 +141,15 @@ message RelatedFieldModelListResponse {
     int32 count = 2;
 }
 
+message RelatedFieldModelPartialUpdateRequest {
+    string uuid = 1;
+    repeated ManyManyModelRequest many_many_obj = 2;
+    string custom_field_name = 3;
+    repeated string _partial_update_fields = 4;
+    string foreign = 5;
+    repeated string many_many = 6;
+}
+
 message RelatedFieldModelRequest {
     string uuid = 1;
     repeated ManyManyModelRequest many_many_obj = 2;
@@ -239,6 +257,7 @@ service UnitTestModelController {
     rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
     rpc List(UnitTestModelListRequest) returns (UnitTestModelListResponse) {}
     rpc ListWithExtraArgs(UnitTestModelListWithExtraArgsRequest) returns (UnitTestModelListExtraArgsResponse) {}
+    rpc PartialUpdate(UnitTestModelPartialUpdateRequest) returns (UnitTestModelResponse) {}
     rpc Retrieve(UnitTestModelRetrieveRequest) returns (UnitTestModelResponse) {}
     rpc Stream(UnitTestModelStreamRequest) returns (stream UnitTestModelResponse) {}
     rpc Update(UnitTestModelRequest) returns (UnitTestModelResponse) {}
@@ -266,6 +285,13 @@ message UnitTestModelListWithExtraArgsRequest {
     bool archived = 1;
 }
 
+message UnitTestModelPartialUpdateRequest {
+    int32 id = 1;
+    string title = 2;
+    string text = 3;
+    repeated string _partial_update_fields = 4;
+}
+
 message UnitTestModelRequest {
     int32 id = 1;
     string title = 2;
@@ -298,6 +324,7 @@ service SpecialFieldsModelController {
     rpc Create(SpecialFieldsModelRequest) returns (SpecialFieldsModelResponse) {}
     rpc Destroy(SpecialFieldsModelDestroyRequest) returns (google.protobuf.Empty) {}
     rpc List(SpecialFieldsModelListRequest) returns (SpecialFieldsModelListResponse) {}
+    rpc PartialUpdate(SpecialFieldsModelPartialUpdateRequest) returns (SpecialFieldsModelResponse) {}
     rpc Retrieve(SpecialFieldsModelRetrieveRequest) returns (CustomRetrieveResponseSpecialFieldsModelResponse) {}
     rpc Update(SpecialFieldsModelRequest) returns (SpecialFieldsModelResponse) {}
 }
@@ -320,6 +347,13 @@ message SpecialFieldsModelListResponse {
     int32 count = 2;
 }
 
+message SpecialFieldsModelPartialUpdateRequest {
+    string uuid = 1;
+    repeated string _partial_update_fields = 2;
+    google.protobuf.Struct meta_datas = 3;
+    repeated int32 list_datas = 4;
+}
+
 message SpecialFieldsModelRequest {
     string uuid = 1;
     google.protobuf.Struct meta_datas = 2;
@@ -517,6 +551,7 @@ service RelatedFieldModelController {
     rpc Create(RelatedFieldModel) returns (RelatedFieldModel) {}
     rpc Destroy(RelatedFieldModelDestroyRequest) returns (google.protobuf.Empty) {}
     rpc List(RelatedFieldModelListRequest) returns (RelatedFieldModelListResponse) {}
+    rpc PartialUpdate(RelatedFieldModelPartialUpdateRequest) returns (RelatedFieldModel) {}
     rpc Retrieve(RelatedFieldModelRetrieveRequest) returns (RelatedFieldModel) {}
     rpc Update(RelatedFieldModel) returns (RelatedFieldModel) {}
 }
@@ -525,6 +560,7 @@ service SpecialFieldsModelController {
     rpc Create(SpecialFieldsModel) returns (SpecialFieldsModel) {}
     rpc Destroy(SpecialFieldsModelDestroyRequest) returns (google.protobuf.Empty) {}
     rpc List(SpecialFieldsModelListRequest) returns (SpecialFieldsModelListResponse) {}
+    rpc PartialUpdate(SpecialFieldsModelPartialUpdateRequest) returns (SpecialFieldsModel) {}
     rpc Retrieve(SpecialFieldsModelRetrieveRequest) returns (CustomRetrieveResponseSpecialFieldsModel) {}
     rpc Update(SpecialFieldsModel) returns (SpecialFieldsModel) {}
 }
@@ -534,6 +570,7 @@ service SyncUnitTestModelController {
     rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
     rpc List(UnitTestModelListRequest) returns (UnitTestModelListResponse) {}
     rpc ListWithExtraArgs(SyncUnitTestModelListWithExtraArgsRequest) returns (UnitTestModelListExtraArgs) {}
+    rpc PartialUpdate(UnitTestModelPartialUpdateRequest) returns (UnitTestModel) {}
     rpc Retrieve(UnitTestModelRetrieveRequest) returns (UnitTestModel) {}
     rpc Stream(UnitTestModelStreamRequest) returns (stream UnitTestModel) {}
     rpc Update(UnitTestModel) returns (UnitTestModel) {}
@@ -544,6 +581,7 @@ service UnitTestModelController {
     rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
     rpc List(UnitTestModelListRequest) returns (UnitTestModelListResponse) {}
     rpc ListWithExtraArgs(UnitTestModelListWithExtraArgsRequest) returns (UnitTestModelListExtraArgs) {}
+    rpc PartialUpdate(UnitTestModelPartialUpdateRequest) returns (UnitTestModel) {}
     rpc Retrieve(UnitTestModelRetrieveRequest) returns (UnitTestModel) {}
     rpc Stream(UnitTestModelStreamRequest) returns (stream UnitTestModel) {}
     rpc Update(UnitTestModel) returns (UnitTestModel) {}
@@ -710,6 +748,19 @@ message RelatedFieldModelListResponse {
     int32 count = 2;
 }
 
+message RelatedFieldModelPartialUpdateRequest {
+    string uuid = 1;
+    ForeignModel foreign_obj = 2;
+    repeated ManyManyModel many_many_obj = 3;
+    int32 slug_test_model = 4;
+    repeated bool slug_reverse_test_model = 5;
+    repeated string slug_many_many = 6;
+    string custom_field_name = 7;
+    repeated string _partial_update_fields = 8;
+    string foreign = 9;
+    repeated string many_many = 10;
+}
+
 message RelatedFieldModelRetrieveRequest {
     string uuid = 1;
 }
@@ -733,6 +784,14 @@ message SpecialFieldsModelListResponse {
     int32 count = 2;
 }
 
+message SpecialFieldsModelPartialUpdateRequest {
+    string uuid = 1;
+    repeated string _partial_update_fields = 2;
+    google.protobuf.Struct meta_datas = 3;
+    repeated int32 list_datas = 4;
+    bytes binary = 5;
+}
+
 message SpecialFieldsModelRetrieveRequest {
     string uuid = 1;
 }
@@ -769,6 +828,13 @@ message UnitTestModelListWithExtraArgsRequest {
     bool archived = 1;
 }
 
+message UnitTestModelPartialUpdateRequest {
+    int32 id = 1;
+    string title = 2;
+    string text = 3;
+    repeated string _partial_update_fields = 4;
+}
+
 message UnitTestModelRetrieveRequest {
     int32 id = 1;
 }
@@ -812,6 +878,7 @@ service RelatedFieldModelController {
     rpc Create(RelatedFieldModelRequest) returns (RelatedFieldModelResponse) {}
     rpc Destroy(RelatedFieldModelDestroyRequest) returns (google.protobuf.Empty) {}
     rpc List(RelatedFieldModelListRequest) returns (RelatedFieldModelListResponse) {}
+    rpc PartialUpdate(RelatedFieldModelPartialUpdateRequest) returns (RelatedFieldModelResponse) {}
     rpc Retrieve(RelatedFieldModelRetrieveRequest) returns (RelatedFieldModelResponse) {}
     rpc Update(RelatedFieldModelRequest) returns (RelatedFieldModelResponse) {}
 }
@@ -820,6 +887,7 @@ service SpecialFieldsModelController {
     rpc Create(SpecialFieldsModelRequest) returns (SpecialFieldsModelResponse) {}
     rpc Destroy(SpecialFieldsModelDestroyRequest) returns (google.protobuf.Empty) {}
     rpc List(SpecialFieldsModelListRequest) returns (SpecialFieldsModelListResponse) {}
+    rpc PartialUpdate(SpecialFieldsModelPartialUpdateRequest) returns (SpecialFieldsModelResponse) {}
     rpc Retrieve(SpecialFieldsModelRetrieveRequest) returns (CustomRetrieveResponseSpecialFieldsModelResponse) {}
     rpc Update(SpecialFieldsModelRequest) returns (SpecialFieldsModelResponse) {}
 }
@@ -829,6 +897,7 @@ service SyncUnitTestModelController {
     rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
     rpc List(UnitTestModelListRequest) returns (UnitTestModelListResponse) {}
     rpc ListWithExtraArgs(SyncUnitTestModelListWithExtraArgsRequest) returns (UnitTestModelListExtraArgsResponse) {}
+    rpc PartialUpdate(UnitTestModelPartialUpdateRequest) returns (UnitTestModelResponse) {}
     rpc Retrieve(UnitTestModelRetrieveRequest) returns (UnitTestModelResponse) {}
     rpc Stream(UnitTestModelStreamRequest) returns (stream UnitTestModelResponse) {}
     rpc Update(UnitTestModelRequest) returns (UnitTestModelResponse) {}
@@ -839,6 +908,7 @@ service UnitTestModelController {
     rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
     rpc List(UnitTestModelListRequest) returns (UnitTestModelListResponse) {}
     rpc ListWithExtraArgs(UnitTestModelListWithExtraArgsRequest) returns (UnitTestModelListExtraArgsResponse) {}
+    rpc PartialUpdate(UnitTestModelPartialUpdateRequest) returns (UnitTestModelResponse) {}
     rpc Retrieve(UnitTestModelRetrieveRequest) returns (UnitTestModelResponse) {}
     rpc Stream(UnitTestModelStreamRequest) returns (stream UnitTestModelResponse) {}
     rpc Update(UnitTestModelRequest) returns (UnitTestModelResponse) {}
@@ -1025,6 +1095,15 @@ message RelatedFieldModelListResponse {
     int32 count = 2;
 }
 
+message RelatedFieldModelPartialUpdateRequest {
+    string uuid = 1;
+    repeated ManyManyModelRequest many_many_obj = 2;
+    string custom_field_name = 3;
+    repeated string _partial_update_fields = 4;
+    string foreign = 5;
+    repeated string many_many = 6;
+}
+
 message RelatedFieldModelRequest {
     string uuid = 1;
     repeated ManyManyModelRequest many_many_obj = 2;
@@ -1061,6 +1140,13 @@ message SpecialFieldsModelListResponse {
     int32 count = 2;
 }
 
+message SpecialFieldsModelPartialUpdateRequest {
+    string uuid = 1;
+    repeated string _partial_update_fields = 2;
+    google.protobuf.Struct meta_datas = 3;
+    repeated int32 list_datas = 4;
+}
+
 message SpecialFieldsModelRequest {
     string uuid = 1;
     google.protobuf.Struct meta_datas = 2;
@@ -1104,6 +1190,13 @@ message UnitTestModelListWithExtraArgsRequest {
     bool archived = 1;
 }
 
+message UnitTestModelPartialUpdateRequest {
+    int32 id = 1;
+    string title = 2;
+    string text = 3;
+    repeated string _partial_update_fields = 4;
+}
+
 message UnitTestModelRequest {
     int32 id = 1;
     string title = 2;
