@@ -1,5 +1,7 @@
 from typing import Dict, List
 
+from asgiref.sync import sync_to_async
+
 from django_socio_grpc.decorators import grpc_action
 from django_socio_grpc.grpc_actions.actions import GRPCActionMixin
 from django_socio_grpc.grpc_actions.placeholders import AttrPlaceholder
@@ -7,7 +9,8 @@ from django_socio_grpc.grpc_actions.placeholders import AttrPlaceholder
 
 class ListIdsMixin(GRPCActionMixin, abstract=True):
     @grpc_action(request=[], response=[{"name": "ids", "type": "repeated int32"}])
-    async def ListIds(self, request, context):
+    @sync_to_async
+    def ListIds(self, request, context):
         pass
 
 
